@@ -16,7 +16,7 @@ use XML::LibXML::PrettyPrint;
 
 use OTRS::OPM::Maker -command;
 
-our $VERSION = 1.11;
+our $VERSION = 1.12;
 
 sub abstract {
     return "build sopm file based on metadata";
@@ -221,7 +221,7 @@ sub _IntroTemplate {
 
     return qq~    <Intro$type Type="post"$version><![CDATA[
             $text
-        </Intro$type>
+        ]]></Intro$type>
     ~;
 }
 
@@ -378,7 +378,7 @@ OTRS::OPM::Maker::Command::sopm - Build .sopm file based on metadata
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 CONFIGURATION
 
